==> download.php?FileName=terralib-5.4.1-ubuntu-18.04.tar.gz: opt/terralib/5.4.1/include/terralib/terralib_buildconfig.h <==
/*  Copyright (C) 2008 National Institute For Space Research (INPE) - Brazil.

    This file is part of the TerraLib - a Framework for building GIS enabled applications.

    TerraLib is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License,
    or (at your option) any later version.

    TerraLib is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with TerraLib. See COPYING. If not, write to
    TerraLib Team at <terralib-team@terralib.org>.
 */

/*!
  \file terralib/terralib_buildconfig.h

  \brief Build configuration flags of TerraLib.
*/

#ifndef __TERRALIB_INTERNAL_TERRALIB_BUILDCONFIG_H__
#define __TERRALIB_INTERNAL_TERRALIB_BUILDCONFIG_H__

#define TERRALIB_DATA_DIR "/home/jenkins/MyBuilds/workspace/terralib-terraview-installer-linux-ubuntu-18.04/solution/build/data"

#define TERRALIB_REPORT_DIR "/home/jenkins/MyBuilds/workspace/terralib-terraview-installer-linux-ubuntu-18.04/solution/build/report"

/* #undef TERRALIB_MOD_ADO_ENABLED */

/* #undef TERRALIB_MOD_ANNOTATIONTEXT_ENABLED */

#define TERRALIB_MOD_CLASSIFICATION_ENABLED

#define TERRALIB_MOD_COLOR_ENABLED

#define TERRALIB_MOD_COMMON_ENABLED

#define TERRALIB_MOD_DATAACCESS_ENABLED

#define TERRALIB_MOD_DATATYPE_ENABLED

#define TERRALIB_MOD_FILTER_ENABLED

#define TERRALIB_MOD_GDAL_ENABLED

#define TERRALIB_MOD_GEOMETRY_ENABLED

#define TERRALIB_MOD_GML_ENABLED

#define TERRALIB_MOD_GRAPH_ENABLED

/* #undef TERRALIB_MOD_LAYOUT_ENABLED */

#define TERRALIB_MOD_MAPTOOLS_ENABLED

#define TERRALIB_MOD_MEMORY_ENABLED

#define TERRALIB_MOD_METADATA_ENABLED

#define TERRALIB_MOD_OGR_ENABLED

/* #undef TERRALIB_MOD_PLUGIN_ENABLED */

#define TERRALIB_MOD_POSTGIS_ENABLED

#define TERRALIB_MOD_QT_APF_ENABLED

/* #undef TERRALIB_MOD_QT_PLUGINS_DATASOURCE_ADO_ENABLED */

#define TERRALIB_MOD_QT_PLUGINS_DATASOURCE_GDAL_ENABLED

/* #undef TERRALIB_MOD_QT_PLUGINS_DATASOURCE_TERRALIB4_ENABLED */

#define TERRALIB_MOD_QT_PLUGINS_DATASOURCE_OGR_ENABLED

#define TERRALIB_MOD_QT_PLUGINS_DATASOURCE_POSTGIS_ENABLED

/* #undef TERRALIB_MOD_QT_PLUGINS_DATASOURCE_WCS_ENABLED */

#define TERRALIB_MOD_QT_PLUGINS_DATASOURCE_WFS_ENABLED

/* #undef TERRALIB_MOD_QT_PLUGINS_DATASOURCE_WMS_ENABLED */

/* #undef TERRALIB_MOD_QT_PLUGINS_LAYOUT_ENABLED */

#define TERRALIB_MOD_QT_PLUGINS_RP_ENABLED

#define TERRALIB_MOD_QT_PLUGINS_VP_ENABLED

#define TERRALIB_MOD_QT_WIDGETS_ENABLED

#define TERRALIB_MOD_RASTER_ENABLED

#define TERRALIB_MOD_RP_ENABLED

#define TERRALIB_MOD_SAM_ENABLED

#define TERRALIB_MOD_SRS_ENABLED

#define TERRALIB_MOD_ST_ENABLED

#define TERRALIB_MOD_STATISTICS_CORE_ENABLED

#define TERRALIB_MOD_STATISTICS_QT_ENABLED

#define TERRALIB_MOD_STMEMORY_ENABLED

#define TERRALIB_MOD_SYMBOLOGY_ENABLED

/* #undef TERRALIB_MOD_TERRALIB4_ENABLED */

#define TERRALIB_MOD_VP_CORE_ENABLED

#define TERRALIB_MOD_VP_QT_ENABLED

#define TERRALIB_MOD_XLINK_ENABLED

#define TERRALIB_MOD_XML_ENABLED

/* #undef TERRALIB_MOD_XSD_ENABLED */

/* #undef TERRALIB_MOD_WCS_ENABLED */

#define TERRALIB_MOD_WFS_ENABLED

/* #undef TERRALIB_MOD_WMS_CORE_ENABLED */

/* #undef TERRALIB_MOD_WMS_QT_ENABLED */

/* #undef TERRALIB_STATIC_BUILD */

#define TERRALIB_AUTOMATIC_INITIALIZATION

#define TERRALIB_BUILD_AS_BUNDLE

/* #undef TERRALIB_BUILD_AS_DEV */

#define TERRALIB_CODEBASE_PATH "/home/jenkins/MyBuilds/workspace/terralib-terraview-installer-linux-ubuntu-18.04"

#define TERRALIB_BUILD_PATH "/home/jenkins/MyBuilds/workspace/terralib-terraview-installer-linux-ubuntu-18.04/solution/build"

#define TERRALIB_INSTALL_PREFIX_PATH "/opt/terralib/5.4.1"

#define TERRALIB_DIR_VAR_NAME "TERRALIB_HOME"

#define TERRALIB_BOOST_ENABLED

#define TERRALIB_GDAL_ENABLED

#if defined(TERRALIB_GDAL_ENABLED)
  #define TERRALIB_GDAL_DATA "/opt/terralib/5.4.1/3rdparty/share/gdal"
#endif

#define TERRALIB_GEOS_ENABLED

/* #undef TERRALIB_GEOSC_ENABLED */

/* #undef TERRALIB_GNU_GETTEXT_ENABLED */

/* #undef TERRALIB_GNU_ICONV_ENABLED */

#define TERRALIB_LIBPQ_ENABLED

#define TERRALIB_LUA_ENABLED

#define TERRALIB_PROJ4_ENABLED

/* #undef TERRALIB_QT4_ENABLED */

#define TERRALIB_QT5_ENABLED

/* #undef TERRALIB_TERRALIB4_ENABLED */

#if defined(TERRALIB_QT4_ENABLED) || defined(TERRALIB_QT5_ENABLED)
  #define TERRALIB_QT_ENABLED
#endif

#define TERRALIB_QWT_ENABLED

#define TERRALIB_QTPROPERTYBROWSER_ENABLED

/* #undef TERRALIB_SCIDB_ENABLED */

/* #undef TERRALIB_SPATIALITE_ENABLED */

/* #undef TERRALIB_SQLITE_ENABLED */

#define TERRALIB_XERCES_ENABLED

#define TERRALIB_LOGGER_ENABLED

#ifdef TERRALIB_LOGGER_ENABLED
  #define TERRALIB_LOGGER_FATAL_ENABLED
/* #undef TERRALIB_LOGGER_ASSERT_ENABLED */
  #define TERRALIB_LOGGER_ERROR_ENABLED
  #define TERRALIB_LOGGER_WARN_ENABLED
  #define TERRALIB_LOGGER_INFO_ENABLED
/* #undef TERRALIB_LOGGER_DEBUG_ENABLED */
/* #undef TERRALIB_LOGGER_TRACE_ENABLED */
#endif

#define TERRALIB_TRANSLATOR_ENABLED

#define TERRALIB_MOD_BINDING_PYTHON_ENABLED
#ifdef TERRALIB_MOD_BINDING_PYTHON_ENABLED
  #define TERRALIB_MOD_BINDING_PYTHON_DIR "python/terralib"
#endif

#endif  // __TERRALIB_INTERNAL_TERRALIB_BUILDCONFIG_H__

==> download.php?FileName=terralib-5.4.2-ubuntu-16.04.tar.gz: opt/terralib/5.4.2/include/terralib/terralib_buildconfig.h <==
/*  Copyright (C) 2008 National Institute For Space Research (INPE) - Brazil.

    This file is part of the TerraLib - a Framework for building GIS enabled applications.

    TerraLib is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License,
    or (at your option) any later version.

    TerraLib is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with TerraLib. See COPYING. If not, write to
    TerraLib Team at <terralib-team@terralib.org>.
 */

/*!
  \file terralib/terralib_buildconfig.h

  \brief Build configuration flags of TerraLib.
*/

#ifndef __TERRALIB_INTERNAL_TERRALIB_BUILDCONFIG_H__
#define __TERRALIB_INTERNAL_TERRALIB_BUILDCONFIG_H__

#define TERRALIB_DATA_DIR "/home/terralib/workspace/terralib-terraview-installer-linux-ubuntu-16.04/solution/build/data"

#define TERRALIB_REPORT_DIR "/home/terralib/workspace/terralib-terraview-installer-linux-ubuntu-16.04/solution/build/report"

/* #undef TERRALIB_MOD_ADO_ENABLED */

/* #undef TERRALIB_MOD_ANNOTATIONTEXT_ENABLED */

#define TERRALIB_MOD_CLASSIFICATION_ENABLED

#define TERRALIB_MOD_COLOR_ENABLED

#define TERRALIB_MOD_COMMON_ENABLED

#define TERRALIB_MOD_DATAACCESS_ENABLED

#define TERRALIB_MOD_DATATYPE_ENABLED

#define TERRALIB_MOD_FILTER_ENABLED

#define TERRALIB_MOD_GDAL_ENABLED

#define TERRALIB_MOD_GEOMETRY_ENABLED

#define TERRALIB_MOD_GML_ENABLED

#define TERRALIB_MOD_GRAPH_ENABLED

/* #undef TERRALIB_MOD_LAYOUT_ENABLED */

#define TERRALIB_MOD_MAPTOOLS_ENABLED

#define TERRALIB_MOD_MEMORY_ENABLED

#define TERRALIB_MOD_METADATA_ENABLED

#define TERRALIB_MOD_OGR_ENABLED

/* #undef TERRALIB_MOD_PLUGIN_ENABLED */

#define TERRALIB_MOD_POSTGIS_ENABLED

#define TERRALIB_MOD_QT_APF_ENABLED

/* #undef TERRALIB_MOD_QT_PLUGINS_DATASOURCE_ADO_ENABLED */

#define TERRALIB_MOD_QT_PLUGINS_DATASOURCE_GDAL_ENABLED

/* #undef TERRALIB_MOD_QT_PLUGINS_DATASOURCE_TERRALIB4_ENABLED */

#define TERRALIB_MOD_QT_PLUGINS_DATASOURCE_OGR_ENABLED

#define TERRALIB_MOD_QT_PLUGINS_DATASOURCE_POSTGIS_ENABLED

/* #undef TERRALIB_MOD_QT_PLUGINS_DATASOURCE_WCS_ENABLED */

#define TERRALIB_MOD_QT_PLUGINS_DATASOURCE_WFS_ENABLED

/* #undef TERRALIB_MOD_QT_PLUGINS_DATASOURCE_WMS_ENABLED */

/* #undef TERRALIB_MOD_QT_PLUGINS_LAYOUT_ENABLED */

#define TERRALIB_MOD_QT_PLUGINS_RP_ENABLED

#define TERRALIB_MOD_QT_PLUGINS_VP_ENABLED

#define TERRALIB_MOD_QT_WIDGETS_ENABLED

#define TERRALIB_MOD_RASTER_ENABLED

#define TERRALIB_MOD_RP_ENABLED

#define TERRALIB_MOD_SAM_ENABLED

#define TERRALIB_MOD_SRS_ENABLED

#define TERRALIB_MOD_ST_ENABLED

#define TERRALIB_MOD_STATISTICS_CORE_ENABLED

#define TERRALIB_MOD_STATISTICS_QT_ENABLED

#define TERRALIB_MOD_STMEMORY_ENABLED

#define TERRALIB_MOD_SYMBOLOGY_ENABLED

/* #undef TERRALIB_MOD_TERRALIB4_ENABLED */

#define TERRALIB_MOD_VP_CORE_ENABLED

#define TERRALIB_MOD_VP_QT_ENABLED

#define TERRALIB_MOD_XLINK_ENABLED

#define TERRALIB_MOD_XML_ENABLED

/* #undef TERRALIB_MOD_XSD_ENABLED */

/* #undef TERRALIB_MOD_WCS_ENABLED */

#define TERRALIB_MOD_WFS_ENABLED

/* #undef TERRALIB_MOD_WMS_CORE_ENABLED */

/* #undef TERRALIB_MOD_WMS_QT_ENABLED */

/* #undef TERRALIB_STATIC_BUILD */

#define TERRALIB_AUTOMATIC_INITIALIZATION

#define TERRALIB_BUILD_AS_BUNDLE

/* #undef TERRALIB_BUILD_AS_DEV */

#define TERRALIB_CODEBASE_PATH "/home/terralib/workspace/terralib-terraview-installer-linux-ubuntu-16.04"

#define TERRALIB_BUILD_PATH "/home/terralib/workspace/terralib-terraview-installer-linux-ubuntu-16.04/solution/build"

#define TERRALIB_INSTALL_PREFIX_PATH "/opt/terralib/5.4.2"

#define TERRALIB_DIR_VAR_NAME "TERRALIB_HOME"

#define TERRALIB_BOOST_ENABLED

#define TERRALIB_GDAL_ENABLED

#if defined(TERRALIB_GDAL_ENABLED)
  #define TERRALIB_GDAL_DATA "/opt/terralib/5.4.2/3rdparty/share/gdal"
#endif

#define TERRALIB_GEOS_ENABLED

/* #undef TERRALIB_GEOSC_ENABLED */

/* #undef TERRALIB_GNU_GETTEXT_ENABLED */

/* #undef TERRALIB_GNU_ICONV_ENABLED */

#define TERRALIB_LIBPQ_ENABLED

#define TERRALIB_LUA_ENABLED

#define TERRALIB_PROJ4_ENABLED

/* #undef TERRALIB_QT4_ENABLED */

#define TERRALIB_QT5_ENABLED

/* #undef TERRALIB_TERRALIB4_ENABLED */

#if defined(TERRALIB_QT4_ENABLED) || defined(TERRALIB_QT5_ENABLED)
  #define TERRALIB_QT_ENABLED
#endif

#define TERRALIB_QWT_ENABLED

#define TERRALIB_QTPROPERTYBROWSER_ENABLED

/* #undef TERRALIB_SCIDB_ENABLED */

/* #undef TERRALIB_SPATIALITE_ENABLED */

/* #undef TERRALIB_SQLITE_ENABLED */

#define TERRALIB_XERCES_ENABLED

#define TERRALIB_LOGGER_ENABLED

#ifdef TERRALIB_LOGGER_ENABLED
  #define TERRALIB_LOGGER_FATAL_ENABLED
/* #undef TERRALIB_LOGGER_ASSERT_ENABLED */
  #define TERRALIB_LOGGER_ERROR_ENABLED
  #define TERRALIB_LOGGER_WARN_ENABLED
  #define TERRALIB_LOGGER_INFO_ENABLED
/* #undef TERRALIB_LOGGER_DEBUG_ENABLED */
/* #undef TERRALIB_LOGGER_TRACE_ENABLED */
#endif

#define TERRALIB_TRANSLATOR_ENABLED

#define TERRALIB_MOD_BINDING_PYTHON_ENABLED
#ifdef TERRALIB_MOD_BINDING_PYTHON_ENABLED
  #define TERRALIB_MOD_BINDING_PYTHON_DIR "python/terralib"
#endif

/* #undef TERRALIB_LEAK_DETECTOR_ENABLED */

#endif  // __TERRALIB_INTERNAL_TERRALIB_BUILDCONFIG_H__
